#  tests for tkwant-1.0.1-py36h24e2160_0 (this is a generated file);
print('===== testing package: tkwant-1.0.1-py36h24e2160_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import sys
import os.path

from pytest import main

import kwant

def test():
    kwant_path = os.path.dirname(os.path.abspath(kwant.__file__))
    sys.exit(main([kwant_path, "-x", "-v"]))

test()
#  --- run_test.py (end) ---

print('===== tkwant-1.0.1-py36h24e2160_0 OK =====');
print("import: 'tkwant'")
import tkwant

